@@ -1,7 +1,7 @@
 /*****************************************************************************\
   HPCupsFilter.h : Interface for HPCupsFilter class
 
-  Copyright (c) 1996 - 2009, Hewlett-Packard Co.
+  Copyright (c) 1996 - 2015, HP Co.
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
@@ -12,7 +12,7 @@
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
-  3. Neither the name of Hewlett-Packard nor the names of its
+  3. Neither the name of HP nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.
 
@@ -96,10 +96,9 @@ private:
     DBusCommunicator m_DBusComm;
 	
 private:
-
     void            closeFilter();
     void            cleanup();
-    void            getLogLevel();
+    //void            getLogLevel();
     DRIVER_ERROR    startPage (cups_page_header2_t *header);
     int             processRasterData(cups_raster_t *cups_raster);
     void            extractBlackPixels(cups_page_header2_t *cups_header,
@@ -119,6 +118,11 @@ private:
     BYTE   *color_raster;
     BITMAPFILEHEADER    bmfh;
     BITMAPINFOHEADER    bmih;
+
+#ifdef UNITTESTING
+    friend class TestHPCupsFilter;
+#endif
+
 };
 
 #endif  // HP_CUPSFILTER_H
